@@ -1,10 +1,10 @@
 use glium::glutin::window::Icon;
-use image::{io::Reader as ImageReader};
+use image::{io::Reader as ImageReader, ImageFormat};
 use std::io::Cursor;
 
 pub fn get_icon() -> Icon {
     let bytes = include_bytes!("../icon.ico");
-    let image = ImageReader::with_format(Cursor::new(bytes), image::guess_format(bytes).unwrap())
+    let image = ImageReader::with_format(Cursor::new(bytes), ImageFormat::Ico)
         .decode()
         .unwrap()
         .into_rgba8();
